/*
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Copyright 2000 by Michael B. Allen
 *
 */

package jcifs.netbios;

import java.net.InetAddress;
import java.net.SocketException;
import jcifs.util.Log;

/**
 * This class is a wrapper for setting all properties of the jcifs netbios client.
 *
 * @version   0.1, 00/03/13
 * @author    Michael B. Allen
 * @since     jcifs-0.1
 */

public final class NbtConfig {

    // supress javadoc constructor summary
    NbtConfig() {}

/**
 * Sets the nameserver(Samba, WINS, ...) the client should use to resolve
 * addresses.
 * @param nameserver the nameserver
 */

    public static void setNameServer( InetAddress nameserver ) {
        if( NbtAddress.client == null ) {
            NbtAddress.nameserver = nameserver;
            return;
        }
        NbtAddress.client.nameserver = NbtAddress.nameserver = nameserver;
    }

/**
 * Sets the broadcast address the name service should use to resovle
 * addresses. If unspecified, the name service will guess the broadcast
 * address by making the low byte 255.
 * @param bCastAddress the broadcast address
 */

    public static void setBroadcastAddress( InetAddress bCastAddress ) {
        if( NbtAddress.client == null ) {
            NbtAddress.bCastAddress = bCastAddress;
            return;
        }
        NbtAddress.client.bCastAddress = NbtAddress.bCastAddress = bCastAddress;
    }

/**
 * Sets the clients node type. This controls it's behavior when doing queries.
 * @param nodeType can be {@link jcifs.netbios.NbtAddress#B_NODE}, {@link jcifs.netbios.NbtAddress#P_NODE}, {@link jcifs.netbios.NbtAddress#M_NODE}, {@link jcifs.netbios.NbtAddress#H_NODE}
 */

    public static void setNodeType( int nodeType ) {
        if( NbtAddress.client == null ) {
            NbtAddress.localhostType = nodeType;
            return;
        }
        NbtAddress.client.nodeType = NbtAddress.localhostType = nodeType;
    }

/**
 * Sets the address caching policy.
 * @param cachePolicy is the number of seconds before a name should expire, 0 for no caching, or -1 for forever
 */

    public static void setCachePolicy( int cachePolicy ) {
        NbtAddress.cachePolicy = cachePolicy;
    }

/**
 * Set's the local hostname the client presents when connecting to hosts.
 * @param name the name the client should masquarade as
 * @param scope 99.9% chance you don't need scope but if you do you will need to set this
 */

    public static void setLocalHostName( String name, String scope ) {
        NbtAddress.localhostName = name;
        NbtAddress.localhostScope = scope;
        NbtAddress.localhost = null;
        if( NbtAddress.client != null ) {
            NbtAddress.client.setLocalHostName( name, scope );
        }
    }

/**
 * Sets the port the client should run on. This might be usefull for Windows
 * 95 clients who only reply to name querys to port 137.
 * @param port the port to run on
 */

    public static void setPort( int port ) {
        if( NbtAddress.client == null ) {
            NbtAddress.port = port;
            return;
        }
        NbtAddress.client.socket.stop();
        NbtAddress.client = null;
        NbtAddress.port = port;
    }

/**
 * Sets the local interface that the client should bind to.
 * @param laddr the local address of the interface
 * @see java.net.DatagramSocket
 */

    public static void setLocalAddress( InetAddress laddr ) {
        if( NbtAddress.client == null ) {
            NbtAddress.laddr = laddr;
            return;
        }
        NbtAddress.client.socket.stop();
        NbtAddress.client = null;
        NbtAddress.laddr = laddr;
    }
}

