/*
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Copyright 2000 by Michael B. Allen
 *
 */

package jcifs.util;

import java.net.DatagramPacket;
import java.net.InetAddress;

/** 
 * Simply encapsulates the {@link java.net.DatagramPacket} and it's reception
 * time.
 *
 * @version   0.1, 00/03/13
 * @author    Michael B. Allen
 * @see       MultiDatagramSocket
 * @see       PacketEventQueue
 * @see       java.net.DatagramPacket
 * @since     jcifs-0.1
 */ 

public class PacketEvent implements Cloneable {
    DatagramPacket p;
    long t;
    PacketEvent next;

    PacketEvent( DatagramPacket p, long t ) {
        this.p = p;
        this.t = t;
    }

/**
 * Retrieve the {@link java.net.DatagramPacket}.
 *
 * @return the packet
 */

    public DatagramPacket getPacket() {
        return p;
    }
/**
 * Return the time the packet was received. The first thing {@link
 * MultiDatagramSocket} does when it receives a packet is note the time. So,
 * if the packet sits in the {@link PacketEventQueue} for a while the time
 * is still accruate.
 *
 * @return the time in milliseconds as a <code>long</code>
 */
    public long getTime() {
        return t;
    }

/**
 * Clone this packet. The cloneing operation is 'deep' in that it copies
 * the data of the underlying packet into a new buffer. This is important
 * for the reasons described in the <b>Important Note:</b> of the {@link
 * MultiDatagramSocket} Class description.
 */
    public synchronized Object clone() {
        PacketEvent result = null;
        try {
            result = (PacketEvent)super.clone();
            byte[] src = p.getData();
            byte[] dst = new byte[src.length];
            int l = p.getLength();
            System.arraycopy( src, 0, dst, 0, l );
            InetAddress a = InetAddress.getByName( p.getAddress().getHostAddress() );
            result.p = new DatagramPacket( dst, l, a, p.getPort() );
            result.t = t;
        } catch( Exception e ) {
            e.printStackTrace();
        }
        return result;
    }
}

